@@ -9,7 +9,7 @@ class PyTwoFaas():
     print self.cToken
 
   def sendAuth(self, clientId, factor, authType):
-    if authType = 'email':
+    if authType == 'email':
       payload = { 'userID' : clientId, 'compTK': self.cToken, 'userNum': factor }
     else:
       payload = { 'userID' : clientId, 'compTK': self.cToken, 'userEmail': factor }
